Package: Rediscover
Type: Package
Title: Identify Mutually Exclusive Mutations
Version: 0.3.3
Authors@R: c(
    person(given = "Juan A.",
           family = "Ferrer-Bonsoms",
           role = c("aut", "cre"),
           email = "jafhernandez@tecnun.es"),
    person(given = "Laura",
           family = "Jareno",
           role = "aut"),
    person(given = "Angel",
           family = "Rubio",
           role = "aut"))
Maintainer: Juan A. Ferrer-Bonsoms <jafhernandez@tecnun.es>
Description: An optimized method for identifying mutually 
    exclusive genomic events.  Its main contribution is a
    statistical analysis based on the Poisson-Binomial 
    distribution that takes into account that some samples
    are more mutated than others. See [Canisius, Sander, John WM Martens,
    and  Lodewyk FA Wessels. (2016)  "A novel independence test for
    somatic alterations in cancer shows that 
    biology drives mutual exclusivity but chance explains
    most co-occurrence." Genome biology 17.1 : 1-17. <doi:10.1186/s13059-016-1114-x>].
    The mutations matrices are sparse matrices. The method developed takes 
    advantage of the advantages of this type of matrix to save 
    time and computing resources.
Depends: R (>= 4.0), Matrix, PoissonBinomial, ShiftConvolvePoibin,
        utils, matrixStats
Imports: maftools, data.table, parallel, RColorBrewer, methods
Suggests: knitr, rmarkdown, RUnit, BiocStyle, dplyr, kableExtra,
        magick, qvalue, testthat (>= 3.0.0)
License: Artistic-2.0
LazyData: true
RoxygenNote: 7.2.3
Encoding: UTF-8
biocViews: mutex
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-12-19 13:17:28 UTC; jafhernandez
Repository: CRAN
Date/Publication: 2025-12-19 17:10:09 UTC
Config/testthat/edition: 3
Author: Juan A. Ferrer-Bonsoms [aut, cre],
  Laura Jareno [aut],
  Angel Rubio [aut]
Built: R 4.6.0; ; 2026-04-26 01:43:28 UTC; unix
