# Generated by roxygen2: do not edit by hand

export(discoversomaticInteractions)
export(getMutex)
export(getMutexAB)
export(getMutexGroup)
export(getPM)
import(Matrix)
import(RColorBrewer)
import(data.table)
import(maftools)
import(methods)
import(parallel)
importFrom(PoissonBinomial,dpbinom)
importFrom(PoissonBinomial,ppbinom)
importFrom(ShiftConvolvePoibin,ppoisbin)
importFrom(matrixStats,rowProds)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,dnorm)
importFrom(stats,gaussian)
importFrom(stats,pbeta)
importFrom(stats,pnorm)
importFrom(stats,rnorm)
importFrom(utils,combn)
importFrom(utils,getFromNamespace)
